Module: Aidp::Interfaces::BinaryCheckerInterface
- Included in:
- AidpBinaryChecker, CachingBinaryChecker, NullBinaryChecker, PathBinaryChecker, StubBinaryChecker
- Defined in:
- lib/aidp/interfaces/binary_checker_interface.rb
Overview
BinaryCheckerInterface defines the contract for checking CLI binary availability. This interface allows for dependency injection of different binary checking implementations, facilitating extraction of provider code into standalone gems.
Instance Method Summary collapse
-
#available?(binary_name) ⇒ Boolean
Check if a binary is available in the system PATH.
-
#path_for(binary_name) ⇒ String?
Get the full path to a binary.
Instance Method Details
#available?(binary_name) ⇒ Boolean
Check if a binary is available in the system PATH.
38 39 40 |
# File 'lib/aidp/interfaces/binary_checker_interface.rb', line 38 def available?(binary_name) raise NotImplementedError, "#{self.class} must implement #available?" end |
#path_for(binary_name) ⇒ String?
Get the full path to a binary.
46 47 48 |
# File 'lib/aidp/interfaces/binary_checker_interface.rb', line 46 def path_for(binary_name) raise NotImplementedError, "#{self.class} must implement #path_for" end |