Module: Aidp::Interfaces::CommandExecutorInterface
- Included in:
- NullExecutor, TtyCommandExecutor
- Defined in:
- lib/aidp/interfaces/command_executor_interface.rb
Overview
CommandExecutorInterface defines the contract for executing shell commands. This interface allows for dependency injection of different command execution backends, facilitating extraction of provider code into standalone gems.
Instance Method Summary collapse
-
#execute(command, args: [], input: nil, timeout: nil, **options) ⇒ CommandResult
Execute a shell command.
Instance Method Details
#execute(command, args: [], input: nil, timeout: nil, **options) ⇒ CommandResult
Execute a shell command.
41 42 43 |
# File 'lib/aidp/interfaces/command_executor_interface.rb', line 41 def execute(command, args: [], input: nil, timeout: nil, **) raise NotImplementedError, "#{self.class} must implement #execute" end |